Crate rust_meth

Crate rust_meth 

Rust method explorer — queries LSP completions and definitions for any Rust type, including third-party crates.

Modules

analyzer
Orchestrates the full LSP session

Structs

LspTransport
A synchronous transport layer for communicating with a Language Server Protocol (LSP) server.
Probe
Represents an ephemeral Cargo project written to disk for LSP interrogation.