parse_definition

Function parse_definition 

pub fn parse_definition(response: &Value) -> Option<Definition>
Normalizes the location array or object mapping payload returned by the LSP server into a Definition.

Panics

Panics if the line position value returned by the LSP protocol fails to map cleanly into a u32.