LspTransport

Struct LspTransport 

pub struct LspTransport { /* private fields */ }
A synchronous transport layer for communicating with a Language Server Protocol (LSP) server.

Implementations

Source

impl LspTransport

pub fn new(child: &mut Child) -> Self

Creates a new LspTransport by taking ownership of the stdin and stdout streams from the provided child process.

Panics

Panics if the child process does not have a captured stdin or stdout stream (e.g., if they weren’t configured with Stdio::piped()).

pub fn send(&mut self, msg: &Value) -> Result<()>

Send a JSON-RPC message.

Errors

Returns an std::io::Error if writing to or flushing the underlying stdin stream fails.

pub fn recv(&mut self) -> Result<Value>

Read the next LSP message (blocks until one arrives).

Errors

Returns an error if:

  • An I/O error occurs while reading from the stdout stream.
  • The stream ends before a valid Content-Length header is parsed.
  • The header value cannot be parsed into a valid size.
  • The message body cannot be parsed as valid JSON.
pub fn recv_until<T>( &mut self, limit: usize, predicate: impl FnMut(&Value) -> Option<T>, ) -> Result<T>

Read messages until predicate returns Some(T), discarding everything else.

Errors

Returns an error if:

  • The underlying Self::recv call fails.
  • The limit number of messages is exhausted without the predicate returning Some(T).
pub fn initialize(process_id: u32, root_uri: &str) -> Value

Constructs an LSP initialize request message.

pub fn initialized() -> Value

Constructs an LSP initialized notification message.

pub fn did_open(uri: &str, text: &str) -> Value

Constructs an LSP textDocument/didOpen notification message.

pub fn definition(id: u64, uri: &str, line: u32, character: u32) -> Value

Constructs an LSP textDocument/definition request message.

pub fn completion(id: u64, uri: &str, line: u32, character: u32) -> Value

Constructs an LSP textDocument/completion request message.

pub fn shutdown(id: u64) -> Value

Constructs an LSP shutdown request message.

pub fn exit() -> Value

Constructs an LSP exit notification message.