Orchestrates the full LSP session
Structs
- Definition
- Contains source definition location mappings returned by an LSP
textDocument/definitioncall. - Method
- Represents a method extracted from a
rust-analyzercompletion list.
Functions
- find_
rust_ analyzer - Locates the
rust-analyzerbinary. - parse_
definition - Normalizes the location array or object mapping payload returned by the LSP server into a
Definition. - parse_
methods - Filters, sanitizes, and deduplicates the raw JSON arrays returned by the LSP completion query.
- query_
definition - Queries
rust-analyzerfor the precise upstream source file declaration layout of a specific method. - query_
methods - Queries
rust-analyzerfor all available methods on a given type type expression.