pub fn parse_definition(response: &Value) -> Option<Definition>Expand description
Normalizes the location array or object mapping payload returned by the LSP server into a Definition.
Panics
Panics if the line position value returned by the LSP protocol fails to map cleanly into a u32.